@@ -31,15 +31,15 @@ def run():
     server.show()
 
 
-def app():
+def qt_app(_):
     global p1
     if qt.main() == 'app closed':
         p1.terminate()
         print('app ended')
     
 
-if __name__ == '__main__':
+def main():
     p1 = multiprocessing.Process(target=run)
     p1.start()
-    app()
+    qt_app('_')
 
