@@ -1195,9 +1195,8 @@ def upload_callback():
     curdoc().add_next_tick_callback(load)
 
 
-def main(doc):
+def main():
     global Main_plot, path_, file_name, mycursor
-    print('curdoc:',curdoc(),'\ndoc:', doc)
     try: myconnect()
     except:
         try: creatbase()
@@ -1209,13 +1208,13 @@ def main(doc):
     except:
         print('Please Choose your Extensions and Data paths\n')
         Error_remind = Div(text='Please Choose your Extensions and Data path...')
-        doc.add_root(Error_remind)
+        curdoc().add_root(Error_remind)
     
     '''upload_button = Button(label="Show")
     upload_button.on_event(ButtonClick, upload_callback)
     curdoc().add_root(upload_button) # 这就是那个按钮'''
 
-    doc.add_next_tick_callback(upload_callback)
+    curdoc().add_next_tick_callback(upload_callback)
 
     
 if __name__ == "main":
